@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Play the tabla!
 
-our $VERSION = '0.0500';
+our $VERSION = '0.0501';
 
 use Moo;
 use File::ShareDir qw(dist_dir);
@@ -92,7 +92,7 @@ Music::Percussion::Tabla - Play the tabla!
 
 =head1 VERSION
 
-version 0.0500
+version 0.0501
 
 =head1 SYNOPSIS
 
@@ -131,9 +131,9 @@ Here are my "non-tabla player" descriptions of the sounds:
    3  62  ?    - slap
    4  63  tin  - ringing mid slap
    5  64  ke   - low knock
-   6  65  ge   - muted ringing low
+   6  65  ga   - muted ringing low
    7  66  ge   - lower
-   8  67  dhun - low-up
+   8  67  ?    - low-up
    9  68  ti   - muted slap
   10  69  ?    - ringing low
   11  70  ti   - flam slap
@@ -146,7 +146,7 @@ Here are my "non-tabla player" descriptions of the sounds:
   18  77  ke   - high slap
   19  78  na   - tap
   20  79  ?    - high knock
-  21  80  dhun - short low-up
+  21  80  ?    - short low-up
   22  81  na   - mid tap
   23  82  ti   - muted tap
   24  83  tin  - mid
@@ -154,7 +154,7 @@ Here are my "non-tabla player" descriptions of the sounds:
   26  85  ta   - loud mid double
   27  86  ti   - slightly more muted
   28  87  tin  - low mid
-  29  88  ta   - ringing mid
+  29  88  tun  - ringing mid
   ...
 
 To play patches by number (for the unknown bols, for instance), do
